@@ -5,7 +5,7 @@ from aioredis import Redis
 from coresvc.base.base_service import BaseService
 import aioredis
 
-from coresvc.serializers import serializer
+from coresvc.serializer import serializer
 
 
 class RedisStore(BaseService):
